=====
konch
=====

.. image:: https://badgen.net/pypi/v/konch
  :alt: pypi badge
  :target: https://pypi.org/project/konch/

.. image:: https://github.com/sloria/konch/actions/workflows/build-release.yml/badge.svg
  :alt: ci status
  :target: https://github.com/sloria/konch/actions/workflows/build-release.yml

.. image:: https://readthedocs.org/projects/konch/badge/
   :target: https://konch.readthedocs.io/
   :alt: Documentation


Configures your Python shell
============================

**konch** is a CLI and configuration utility for the Python shell, optimized for simplicity and productivity.

- **Automatically import** any object upon startup
- **Simple**, per-project configuration in a single file (it's just Python code)
- **No external dependencies**
- Uses **IPython**, **BPython**, or **ptpython** if available, and falls back to built-in interpreter
- Automatically load **IPython extensions**

.. image:: https://user-images.githubusercontent.com/2379650/51432821-2ce68180-1c0c-11e9-9c8d-8053a1b99818.gif
    :alt: Demo
    :target: https://konch.readthedocs.io


`https://konch.readthedocs.io <https://konch.readthedocs.io>`_
==============================================================
